# Changelog

## meteors 0.0.2 (2024-08-11)

- No release
- Refined package structure - simple modules for models and visualisation, installation using toml file
- Spectral attributions using LIME
- CUDA compatibility of LIME

## meteors 0.0.1 (2024-06-02)

- No release
- Prepared a simple draft of package along with some ideas and sample files for implementation of LIME for hyperspectral images.
- Segmentation mask for LIME using slic
- Spatial attributions using LIME
